@@ -8,7 +8,7 @@ import time
 def start_hub_serve(port, passwd, sync):
     hub = TaskHub(sync)
     HubManager.register('get_hub', callable=lambda: hub)
-    hubmanager = HubManager(address=("localhost", port),
+    hubmanager = HubManager(address=("0.0.0.0", port),
                             authkey=passwd.encode("utf-8"))
     serve = hubmanager.get_server()
     serve.serve_forever()
